import bpy


bl_info = {
    "name": "only_selected_fcu_keys_toggle",
    "blender": (3, 6, 0),
    "category": "Animation",
}


class OnlySelectedFcuKeysToggle(bpy.types.Operator):
    """Toggle the user pref setting for showing only keys of selected FCurves"""
    bl_idname = "graph.only_selected_fcu_keys_toggle"
    bl_label = "Only Show Selected FCurve Keyframes"
    bl_options = {"REGISTER", "UNDO"}

    def execute(self, context):
        bpy.context.preferences.edit.show_only_selected_curve_keyframes = not bpy.context.preferences.edit.show_only_selected_curve_keyframes
        return {"FINISHED"}


def menu_func(self, context):
    self.layout.separator()
    self.layout.operator(OnlySelectedFcuKeysToggle.bl_idname,
                         text="Toggle Only Selected FCurve Keyframes")
    self.layout.prop(
        bpy.context.preferences.edit, "show_only_selected_curve_keyframes")


_CLASSES = [
    OnlySelectedFcuKeysToggle,
]


def register():
    for c in _CLASSES:
        bpy.utils.register_class(c)
    bpy.types.GRAPH_MT_view.append(menu_func)


def unregister():
    for c in reversed(_CLASSES):
        bpy.utils.unregister_class(c)

    bpy.types.GRAPH_MT_view.remove(menu_func)
